﻿using System;
using MBN;
using MBN.Enums;
using MBN.Modules;
using Microsoft.SPOT;
using System.Threading;

namespace Examples
{
    public class Program
    {
        private static DHT22Click _dht22;

        public static void Main()
        {
            Debug.Print("Started");

            _dht22 = new DHT22Click(Hardware.SocketFour)
            {
                SamplingFrequency = new TimeSpan(0, 0, 0, 3),
                TemperatureUnit = TemperatureUnits.Celsius
            };

            _dht22.SensorError += _dgt22_SensorError;

            Debug.Print("Version Info - " + _dht22.DriverVersion);
            Debug.Print(_dht22.DewPoint.ToString());

            /* Uncomment the following two lines for Continuous/Event Driven Measurement Mode.*/
            _dht22.TemperatureHumidityMeasured += _dhtt22_OnMeasurement;
            _dht22.StartContinuousMeasurements();

            // Or Un-Comment to read temperature and Humidity Properties in the capture thread.
            //new Thread(Capture).Start();


            Thread.Sleep(Timeout.Infinite);
        }

        private static void _dgt22_SensorError(object sender, string errorMessage)
        {
            Debug.Print(errorMessage);
        }

        private static void _dhtt22_OnMeasurement(object sender, float temperature, float humidity)
        {
            Debug.Print("---------Event Driven----------");
            Debug.Print("Temperature - " + temperature.ToString("f2") + (_dht22.TemperatureUnit == TemperatureUnits.Celsius ? "°C" : _dht22.TemperatureUnit == TemperatureUnits.Fahrenheit ? " °F" : "°K"));
            Debug.Print("Humidity - " + humidity.ToString("f2") + " %RH");
            Debug.Print("Dew Point - " + _dht22.DewPoint.ToString("F2") + (_dht22.TemperatureUnit == TemperatureUnits.Celsius ? "°C" : _dht22.TemperatureUnit == TemperatureUnits.Fahrenheit ? " °F" : "°K") + "\r\n");
        }

        private static void Capture()
        {
            Debug.Print("\n--------Polling the Properties-----------");

            while (true)
            {
                _dht22.RequestMeasurement();

                var temperature = (float)_dht22.Temperature;
                var humidity = (float)_dht22.Humidity;
                var dewPoint = _dht22.DewPoint;

                Debug.Print("Temperature - " + temperature.ToString("f2") + (_dht22.TemperatureUnit == TemperatureUnits.Celsius ? "°C" : _dht22.TemperatureUnit == TemperatureUnits.Fahrenheit ? " °F" : "°K"));
                Debug.Print("Humidity - " + humidity.ToString("f2") + " %RH");
                Debug.Print("Dew Point - " + dewPoint.ToString("F2") + (_dht22.TemperatureUnit == TemperatureUnits.Celsius ? "°C" : _dht22.TemperatureUnit == TemperatureUnits.Fahrenheit ? " °F" : "°K") + "\r\n");
                Thread.Sleep(3000);
            }
        }
    }
}
